@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Exception::Reporter::Dumpable::File;
+package Exception::Reporter::Dumpable::File 0.015;
 # ABSTRACT: a dumpable object for a file on disk
-$Exception::Reporter::Dumpable::File::VERSION = '0.014';
+
 #pod =head1 SYNOPSIS
 #pod
 #pod   $reporter->report_exception(
@@ -127,7 +127,7 @@ Exception::Reporter::Dumpable::File - a dumpable object for a file on disk
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -148,6 +148,18 @@ L<Exception::Reporter::Summarizer::File> in your summarizers.
 Right now, file content is read as soon as the file is constructed.  This may
 change in the future.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 new
@@ -173,7 +185,7 @@ expect File::Error objects, or something like that.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
