@@ -1,14 +1,14 @@
 use strict;
 use warnings;
-package Exception::Reporter::Sender::Email;
+package Exception::Reporter::Sender::Email 0.015;
 # ABSTRACT: a report sender that sends detailed dumps via email
-$Exception::Reporter::Sender::Email::VERSION = '0.014';
+
 use parent 'Exception::Reporter::Sender';
 
 #pod =head1 SYNOPSIS
 #pod
 #pod   my $sender = Exception::Reporter::Sender::Email->new({
-#pod     from => 'root',
+#pod     from => 'root@example.com',
 #pod     to   => 'Beloved SysAdmins <sysadmins@example.com>',
 #pod   });
 #pod
@@ -37,7 +37,7 @@ use parent 'Exception::Reporter::Sender';
 #pod =cut
 
 use Digest::MD5 ();
-use Email::Address ();
+use Email::Address::XS ();
 use Email::MIME::Creator ();
 use Email::MessageID ();
 use Email::Sender::Simple ();
@@ -50,11 +50,11 @@ sub new {
   my $from = $arg->{from} || Carp::confess("missing 'from' argument");
   my $to   = $arg->{to}   || Carp::confess("missing 'to' argument"),
 
-  ($from) = Email::Address->parse($from);
-  ($to)   = [ map {; Email::Address->parse($_) } (ref $to ? @$to : $to) ];
+  ($from) = Email::Address::XS->parse($from);
+  ($to)   = [ map {; Email::Address::XS->parse($_) } (ref $to ? @$to : $to) ];
 
   # Allow mail from a simple, bare local-part like "root" -- rjbs, 2012-07-03
-  $from = Email::Address->new(undef, $arg->{from})
+  $from = Email::Address::XS->new(undef, $arg->{from})
     if ! $from and $arg->{from} =~ /\A[-.0-9a-zA-Z]+\z/;
 
   Carp::confess("couldn't interpret $arg->{from} as an email address")
@@ -276,12 +276,12 @@ Exception::Reporter::Sender::Email - a report sender that sends detailed dumps v
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
   my $sender = Exception::Reporter::Sender::Email->new({
-    from => 'root',
+    from => 'root@example.com',
     to   => 'Beloved SysAdmins <sysadmins@example.com>',
   });
 
@@ -333,6 +333,18 @@ subclass.
 
 The return value of C<send_report> is not defined.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 send_email
@@ -351,7 +363,7 @@ issued.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
