@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Exception::Reporter::Summarizer;
+package Exception::Reporter::Summarizer 0.015;
 # ABSTRACT: a thing that summarizes dumpables for reporting
-$Exception::Reporter::Summarizer::VERSION = '0.014';
+
 use Carp ();
 use Scalar::Util ();
 
@@ -67,7 +67,7 @@ Exception::Reporter::Summarizer - a thing that summarizes dumpables for reportin
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 OVERVIEW
 
@@ -78,9 +78,21 @@ will cause an exception to be thrown.
 A C<sanitize_filename> method is also provided, which turns a vaguely
 filename-like string into a safer filename string.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
