@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Exception::Reporter::Summarizer::Email;
+package Exception::Reporter::Summarizer::Email 0.015;
 # ABSTRACT: a summarizer for Email::Simple objects
-$Exception::Reporter::Summarizer::Email::VERSION = '0.014';
+
 use parent 'Exception::Reporter::Summarizer';
 
 #pod =head1 OVERVIEW
@@ -49,7 +49,7 @@ Exception::Reporter::Summarizer::Email - a summarizer for Email::Simple objects
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 OVERVIEW
 
@@ -57,9 +57,21 @@ This summarizer will only summarize Email::Simple (or subclass) objects.  The
 emails will be summarized as C<message/rfc822> data containing the
 stringification of the message.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
