@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Exception::Reporter::Summarizer::ExceptionClass;
+package Exception::Reporter::Summarizer::ExceptionClass 0.015;
 # ABSTRACT: a summarizer for Exception::Class exceptions
-$Exception::Reporter::Summarizer::ExceptionClass::VERSION = '0.014';
+
 use parent 'Exception::Reporter::Summarizer';
 
 #pod =head1 OVERVIEW
@@ -105,7 +105,7 @@ Exception::Reporter::Summarizer::ExceptionClass - a summarizer for Exception::Cl
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 OVERVIEW
 
@@ -117,9 +117,21 @@ will result in between one and four summaries:
   * if available, the stringification of the exception's stack trace
   * if any fields are defined, a dump of the exception's fields
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
